import webpack from 'webpack'
import path from 'path'
import WebpackShellPlugin from 'webpack-shell-plugin'
import buildWBConfig from './webpack.base.cofig'
import { argv } from 'yargs'
const type = typeof argv.env === 'string' ? argv.env : ''
let config = null

//test环境
if (/test/.test(type)) {
    let testNum = type.match(/\d+/)[0]
    config = buildWBConfig('test', testNum)
    config.webpackConfig.plugins = (config.webpackConfig.plugins || []).concat([
        new webpack.optimize.UglifyJsPlugin({
            compress: {
                warnings: false
            }
        })
    ])
} else if (type == 'product' || type == 'zip') {
    //预发布环境
    config = buildWBConfig('production', 0)
    let now = new Date()
    let getMonth = (now) => {
        let month = now.getMonth() + 1
        if (month < 10) {
            return '0' + month
        } else {
            return month
        }
    }
    let dateFile = now.getFullYear() + '' + getMonth(now)
    config.webpackConfig.output.path += ('/' + dateFile)

    //cdn路径
    config.webpackConfig.output.publicPath = `https://s.geilicdn.com/CPC/${config.baseConfig.module_id}/${dateFile}`

    //添加JS压缩
    config.webpackConfig.plugins = (config.webpackConfig.plugins || []).concat([
        new webpack.optimize.UglifyJsPlugin({
            compress: {
                warnings: false
            }
        })
    ])

    //正式环境
    if (type == 'zip') {

        //执行shell命令，进行打包
        config.webpackConfig.plugins = (config.webpackConfig.plugins || []).concat([
            new WebpackShellPlugin({
                onBuildStart: ['rm -rf build && echo "开始打包"'],
                onBuildExit: [`sh config/zip.sh ${config.baseConfig.module_id}`]
            }),
        ])
    }
} else {
    // 开发环境
    config = buildWBConfig('development', 0)
    config.webpackConfig.devtool = 'source-map'
    config.webpackConfig.watch = true

    config.webpackConfig.output.publicPath = '/'

    //webpack devServer配置，绑定host测试需要添加allowedHosts

    config.webpackConfig.devServer = {
        host: '0.0.0.0',
        allowedHosts: []
    }
}
export default config.webpackConfig